#
# spec file for package python-cliff
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-cliff
Version:        2.4.0
Release:        4.4
Url:            https://github.com/dreamhost/cliff
Summary:        Command Line Interface Formulation Framework
License:        Apache-2.0
Group:          Development/Languages/Python
Source:         https://pypi.io/packages/source/c/cliff/cliff-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-argparse
BuildRequires:  python-devel
BuildRequires:  python-setuptools
# Test requirements:
BuildRequires:  python-PrettyTable
BuildRequires:  python-Sphinx
BuildRequires:  python-cmd2
BuildRequires:  python-coverage >= 3.6
BuildRequires:  python-httplib2 >= 0.7.5
BuildRequires:  python-mock >= 2.0
BuildRequires:  python-nose
BuildRequires:  python-oslosphinx
BuildRequires:  python-pbr
BuildRequires:  python-pyparsing >= 2.0.7
BuildRequires:  python-six
BuildRequires:  python-stevedore
Requires:       python-PrettyTable >= 0.7
Requires:       python-PyYAML >= 3.10.0
Requires:       python-cmd2 >= 0.6.7
Requires:       python-pyparsing >= 2.0.7
Requires:       python-six >= 1.9.0
Requires:       python-stevedore >= 1.17.1
Requires:       python-unicodecsv >= 0.8.0
BuildArch:      noarch

%description
cliff is a framework for building command line programs. It uses
setuptools entry points to provide subcommands, output formatters, and
other extensions.

%package doc
Summary:        Command Line Interface Formulation Framework - Documentation
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%description doc
cliff is a framework for building command line programs. It uses
setuptools entry points to provide subcommands, output formatters, and
other extensions.

This package contains documentation files for %{name}.

%prep
%setup -q -n cliff-%{version}

%build
python setup.py build
python setup.py build_sphinx

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
echo > test-requirements.txt
echo > requirements.txt
python setup.py test

%files
%defattr(-,root,root,-)
%doc LICENSE README.rst
%{python_sitelib}/*

%files doc
%defattr(-,root,root,-)
%doc doc/build/html demoapp

%changelog
* Fri Feb 10 2017 tbechtold@suse.com
- update to 2.4.0:
  * Remove tox environments that no longer work
  * Fix command order
  * Show team and repo badges on README
  * Add print_empty parameter
  * ignore Command docstring when looking for descriptions
  * let the Command get its one-liner description from a class attribute
  * flake8 fix
  * Replace dashes and colons when using bash formatter
  * Show entire command in error message
  * Updated from global requirements
  * Updated from global requirements
  * Fix spelling mistake
  * Add Python 3.5 classifier and venv
  * Updated from global requirements
  * Changed the home-page link
  * Add Apache 2.0 license to source file
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Clean imports in code
  * [doc]Fix URL for 'setuptools entry points'
  * Fix a typo in comment
- Remove relax-sphinx-requirement.patch . No longer needed.
* Tue Oct  4 2016 tbechtold@suse.com
  update to version 2.2.0
  * Fixed broken link
  * pep8: fix F405 error
  * add formattable columns concept
  * command: make run() return take_action() value
  * Fix cliff URLs in doc and demoapp
  * Avoid ASCII encoding errors when output is redirected
  * Fix Command class doc typo
  * Remove announce.rst
  * Updated from global requirements
  * Add tests, cover more cases
* Thu Jul  7 2016 tbechtold@suse.com
- Switch to pypi.io as Source url
* Thu Jul  7 2016 tbechtold@suse.com
- update to 2.1.0:
  * Updated from global requirements
  * Update --max-width help
  * Add more test coverage for shell formatter
  * Add more test coverage for CSV formatter
  * Support multiple sub commands in completion
  * Factorize more test data
  * Factorize some test data
  * Factorize common test code
  * Factorize argparse importing
  * Updated from global requirements
  * Updated from global requirements
  * Add CLIFF_MAX_TERM_WIDTH envvar to complement --max-width
  * Fix prettytable.PrettyTable().max_width wrong usage
  * Fix AttributeError when entry point load failed
  * Distinguish no existed columns in ShowOne
  * Refactor HelpCommand
  * Updated from global requirements
  * Remove httplib2 from test-requirements.txt
  * Sync help message for --help
  * handle empty list in table formatter
  * Drop Python 2.6 support
  * Revert "app,command: disallow abbrev by default"
  * Fixes terminal_width on Windows
  * Updated from global requirements
  * remove openstack-common.conf
  * Add doc for deferred_help parameter
  * Fix pep8 failure
  * app,command: disallow abbrev by default
  * app: work-around abbrev
  * remove unnecessary dependency on argparse
  * Make verbose and quiet mutually exclusive
  * setup: fix Python versions classifiers
  * Don't import unused logging
  * Don't use non-existent method of Mock
  * Replace dashes with underscores in bash completion
  * Updated from global requirements
  * Resize columns to fit screen width
  * fix fuzzy search for same-distance case
  * Correct path to docs
  * only use unicodecsv for python 2.x
  * Fix test class docstring for py 3.5
- Adjust Requires and BuildRequires
* Wed Sep 16 2015 tbechtold@suse.com
- update to 1.15.0:
  * Replace '\r' with ' ' for prettytable
  * Implement a json formatter in cliff
  * Implement a yaml formatter in cliff
  * Updated from global requirements
  * Improve help messages
- Adjust Requires according to requirements.txt
* Fri Aug 21 2015 tbechtold@suse.com
- update to 1.14.0:
  * Add csv formatter test
  * Fix encoding issue with the default python csv output
  * Remove py26 as a default test from tox.ini
  * Set demo app up with deferred help
  * Add command fuzzy matching
  * Updated from global requirements
  * Remove requirements.txt from tox.ini
  * Updated from global requirements
  * Updated from global requirements
  * Allow subcommands to accept --help when using 'deferred_help'
  * Updated from global requirements
  * Fix logging config in demo app
  * Use base command for help test
  * Updated from global requirements
  * Include the automatically-generated changelog
  * Updated from global requirements
- Adjust Requires according to requirements.txt
- Refreshed relax-sphinx-requirement.patch
* Fri Jul 24 2015 seife+obs@b1-systems.com
- Fix build for RHEL7 by nulling test requirements
* Tue Jun 23 2015 dmueller@suse.com
- update to 1.13.0:
  * Fix object has no attribute debug error
  * Add some docs for list value formatter
  * Add value format for list command
  * Updated from global requirements
  * Remove run_cross_tests.sh
  * fix author contact details
  * Print help on help command
  * Do not check requirements when loading plugins
- add relax-sphinx-requirement.patch
* Tue Mar 10 2015 tbechtold@suse.com
- update to 1.10.1:
  * Document print_help_if_requested method
  * Allow to call initialize_app when running --help
  * Hide prompt in batch/pipe mode
  * Correct completion in interactive mode
  * Fix pep8 tests for lambda
  * Updated from global requirements
  * Fix git repo urls in tox.ini
  * Add deprecated attribute to commands
  * Workflow documentation is now in infra-manual
- Adjust Requires according to requirements.txt
* Thu Jan  8 2015 tbechtold@suse.com
- update to 1.9.0:
  * print the real error cmd argument
  * Updated from global requirements
  * Update link to docs in README
  * Bring doc build up to standard
  * Add pbr to installation requirements
  * Add more detail to the README
  * Updated from global requirements
  * Add docs environment to tox.ini
  * mock.assert_called_once() is not a valid method
  * Work toward Python 3.4 support and testing
  * warn against sorting requirements
- Adjust Requires according to requirements.txt
- Adjust BuildRequires accroding to test-requirements.txt
- Fix build path for documentation
* Sat Sep 13 2014 tbechtold@suse.com
- update to 1.7.0:
  * Add release notes for 1.7.0
  * Fix stable integration tests
  * Updated from global requirements
  * Clean up default tox environment list
  * Do not allow wheels for stable tests
  * Set the main logger name to match the application
  * CSV formatter should use system-dependent line ending
  * Make show option compatible with Python 2.6
  * Use six.add_metaclass instead of __metaclass__
  * fixed typos found by RETF rules
  * The --variable option to shell format is redundant
  * Expose load_commands publicly
  * Fix wrong method name assert_called_once
  * Updated from global requirements
  * Fix pep8 failures on rule E265
* Thu Jun 26 2014 dmueller@suse.com
- update to 1.6.1:
  * Remove PrettyTable from documentation requirements
  * Fix a bug in ShellFormatter's escaping of double quotes in strings
  * Import run_cross_tests.sh from oslo-incubator
  * add doc requirements to venv
  * Add max-width support for table formatter
  * Add value only output formattter
  * Update readme with links to bug tracker and source
  * Move pep8 dependency into pep8 tox test
  * Fix doc build with Python 2.6.x
  * Fix interactive mode with command line args
  * Update .gitreview after repo rename
  * Escape double quotes in shell formatter
  * Add unit test for shell formatter
  * Rename private attribute to avoid conflict
  * Sync with global requirements
  * Add integration tests with known consumers
  * update history for previous change
  * Make the formatters a private part of the command
- 0001-Fix-doc-build-with-Python-2.6.x.patch, 0001-Move-pep8-dependency-into-pep8-tox-test.patch,
  remove-distribute-dep.patch: Merged upstream
* Thu Feb 13 2014 dmueller@suse.com
- add 0001-Move-pep8-dependency-into-pep8-tox-test.patch: remove global pep8 dependency
* Tue Jan 21 2014 dmueller@suse.com
- update to 1.5.2:
  * Fix the arguments passed to commands when they are instantiated to
  pull out help.
  * Add bash command completion.
  * Use stevedore to load formatter plugins
  * Use pbr for packaging
- add remove-distribute-dep.patch: remove distribute dependency
- add 0001-Fix-doc-build-with-Python-2.6.x.patch: Fix build with python 2.6
* Fri Sep 27 2013 dmueller@suse.com
- update to 1.4.5:
  * Update the pyparsing dependency to a version that supports both
  Python 2 and Python 3.
  * Add PyPy testing.
- remove patches that went upstream:
  * remove 0001-Require-pyparsing-2.0.1.patch
  * remove relax-cmd2-requires.diff
- fix requires
* Tue Sep 17 2013 speilicke@suse.com
- Add 0001-Require-pyparsing-2.0.1.patch: Allow running with pyparsing>=2.0.1
* Mon Sep  9 2013 dmueller@suse.com
- add relax-cmd2-requires.diff: Allow 0.6.6.1 or newer
* Tue Sep  3 2013 dmueller@suse.com
- update to 1.4.4:
  - Provide better error handling for unknown commands run from the
  command line. (Contributed by Christophe Chauvet.)
* Thu Jun 27 2013 speilicke@suse.com
- Update to version 1.4:
  + Upstream provides no changelog
* Fri May  3 2013 speilicke@suse.com
- Update to version 1.3.3:
  + Upstreamed:
  - 0001-Restore-compatibility-with-Prettytable-0.7.2.patch
  - ignore-cmd2-requires.diff:
* Thu May  2 2013 dmueller@suse.com
- add 0001-Restore-compatibility-with-Prettytable-0.7.2.patch
* Tue Apr 30 2013 dmueller@suse.com
- add ignore-cmd2-requires.diff:
  loosen cmd2 version requires
* Thu Apr 25 2013 dmueller@suse.com
- update to 1.3.2:
  - Add ``convert_underscores`` parameter to ``CommandManager`` ``__init__``
    method to allow underscores to be used in command names. This optional
    argument is defaulted to True to maintain current behavior.
  (contributed by Joe Server)
  - Use flake8_ for style checking.
  - Relax version requirement for PrettyTable dependency to allow
    point releases of 0.7.
* Wed Apr 24 2013 dmueller@suse.com
- buildrequire the right mock version
* Mon Mar 18 2013 dmueller@suse.com
- tighten requires on pyparsing
* Wed Mar 13 2013 dmueller@suse.com
- add prettytable-0.7x.diff:
  - Be compatible with PrettyTable 0.7
- tighten rpm dependencies
* Tue Mar 12 2013 dmueller@suse.com
- Update to 1.3.1:
  - Sort list of commands in interactive help mode.
  - Fix a dependency issue with PyParsing until the cmd2 package can
    release an update setting the version of its dependency based on the
    Python version.
* Fri Nov  9 2012 saschpe@suse.de
- Update to version 1.3:
  + Upstream provides no changelog
- Split out documentation
- Really run testsuite
* Fri Jul 27 2012 saschpe@suse.de
- Add needed runtime requirements
- Run testsuite
- Set license to Apache-2.0
* Fri Jul 27 2012 cthiel@suse.com
- initial package (version 1.0)
